@@ -4,6 +4,7 @@
  *
  * photography.h: photography interface for digital imaging
  *
+ *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Library General Public
  * License as published by the Free Software Foundation; either
@@ -16,8 +17,8 @@
  *
  * You should have received a copy of the GNU Library General Public
  * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 51 Franklin St, Fifth Floor,
- * Boston, MA 02110-1301, USA.
+ * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
+ * Boston, MA 02111-1307, USA.
  */
 
 #ifndef __GST_PHOTOGRAPHY_H__
@@ -29,7 +30,6 @@
 #endif
 
 #include <gst/gst.h>
-#include <gst/interfaces/photography-prelude.h>
 #include <gst/interfaces/photography-enumtypes.h>
 
 G_BEGIN_DECLS
@@ -109,32 +109,32 @@ G_BEGIN_DECLS
 #define MAX_WHITE_POINT_VALUES 4
 
 /* Interface property names */
-#define GST_PHOTOGRAPHY_PROP_WB_MODE            "white-balance-mode"
-#define GST_PHOTOGRAPHY_PROP_COLOR_TONE         "color-tone-mode"
-#define GST_PHOTOGRAPHY_PROP_SCENE_MODE         "scene-mode"
-#define GST_PHOTOGRAPHY_PROP_FLASH_MODE         "flash-mode"
-#define GST_PHOTOGRAPHY_PROP_NOISE_REDUCTION    "noise-reduction"
-#define GST_PHOTOGRAPHY_PROP_FOCUS_STATUS       "focus-status"
-#define GST_PHOTOGRAPHY_PROP_CAPABILITIES       "capabilities"
-#define GST_PHOTOGRAPHY_PROP_SHAKE_RISK         "shake-risk"
-#define GST_PHOTOGRAPHY_PROP_EV_COMP            "ev-compensation"
-#define GST_PHOTOGRAPHY_PROP_ISO_SPEED          "iso-speed"
-#define GST_PHOTOGRAPHY_PROP_APERTURE           "aperture"
-#define GST_PHOTOGRAPHY_PROP_EXPOSURE_TIME      "exposure-time"
+#define GST_PHOTOGRAPHY_PROP_WB_MODE      "white-balance-mode"
+#define GST_PHOTOGRAPHY_PROP_COLOR_TONE   "color-tone-mode"
+#define GST_PHOTOGRAPHY_PROP_SCENE_MODE   "scene-mode"
+#define GST_PHOTOGRAPHY_PROP_FLASH_MODE   "flash-mode"
+#define GST_PHOTOGRAPHY_PROP_NOISE_REDUCTION   "noise-reduction"
+#define GST_PHOTOGRAPHY_PROP_FOCUS_STATUS "focus-status"
+#define GST_PHOTOGRAPHY_PROP_CAPABILITIES "capabilities"
+#define GST_PHOTOGRAPHY_PROP_SHAKE_RISK   "shake-risk"
+#define GST_PHOTOGRAPHY_PROP_EV_COMP      "ev-compensation"
+#define GST_PHOTOGRAPHY_PROP_ISO_SPEED    "iso-speed"
+#define GST_PHOTOGRAPHY_PROP_APERTURE     "aperture"
+#define GST_PHOTOGRAPHY_PROP_EXPOSURE_TIME     "exposure-time"
 #define GST_PHOTOGRAPHY_PROP_IMAGE_CAPTURE_SUPPORTED_CAPS \
-                                                "image-capture-supported-caps"
+    "image-capture-supported-caps"
 #define GST_PHOTOGRAPHY_PROP_IMAGE_PREVIEW_SUPPORTED_CAPS \
-                                                "image-preview-supported-caps"
-#define GST_PHOTOGRAPHY_PROP_FLICKER_MODE       "flicker-mode"
-#define GST_PHOTOGRAPHY_PROP_FOCUS_MODE         "focus-mode"
-#define GST_PHOTOGRAPHY_PROP_ZOOM               "zoom"
-#define GST_PHOTOGRAPHY_PROP_COLOR_TEMPERATURE  "color-temperature"
-#define GST_PHOTOGRAPHY_PROP_WHITE_POINT        "white-point"
-#define GST_PHOTOGRAPHY_PROP_ANALOG_GAIN        "analog-gain"
-#define GST_PHOTOGRAPHY_PROP_EXPOSURE_MODE      "exposure-mode"
-#define GST_PHOTOGRAPHY_PROP_LENS_FOCUS         "lens-focus"
-#define GST_PHOTOGRAPHY_PROP_MIN_EXPOSURE_TIME  "min-exposure-time"
-#define GST_PHOTOGRAPHY_PROP_MAX_EXPOSURE_TIME  "max-exposure-time"
+    "image-preview-supported-caps"
+#define GST_PHOTOGRAPHY_PROP_FLICKER_MODE "flicker-mode"
+#define GST_PHOTOGRAPHY_PROP_FOCUS_MODE   "focus-mode"
+#define GST_PHOTOGRAPHY_PROP_ZOOM   "zoom"
+#define GST_PHOTOGRAPHY_PROP_COLOR_TEMPERATURE "color-temperature"
+#define GST_PHOTOGRAPHY_PROP_WHITE_POINT  "white-point"
+#define GST_PHOTOGRAPHY_PROP_ANALOG_GAIN  "analog-gain"
+#define GST_PHOTOGRAPHY_PROP_EXPOSURE_MODE     "exposure-mode"
+#define GST_PHOTOGRAPHY_PROP_LENS_FOCUS   "lens-focus"
+#define GST_PHOTOGRAPHY_PROP_MIN_EXPOSURE_TIME "min-exposure-time"
+#define GST_PHOTOGRAPHY_PROP_MAX_EXPOSURE_TIME "max-exposure-time"
 
 /**
  * GstPhotography:
@@ -159,14 +159,16 @@ typedef struct _GstPhotography GstPhotography;
  * remaining noise.
  *
  * Noise Reduction features of a photography capture or filter element.
+ *
+ * Since: 0.10.21
  */
 typedef enum
 {
-  GST_PHOTOGRAPHY_NOISE_REDUCTION_BAYER    = (1 << 0),
-  GST_PHOTOGRAPHY_NOISE_REDUCTION_YCC      = (1 << 1),
-  GST_PHOTOGRAPHY_NOISE_REDUCTION_TEMPORAL = (1 << 2),
-  GST_PHOTOGRAPHY_NOISE_REDUCTION_FIXED    = (1 << 3),
-  GST_PHOTOGRAPHY_NOISE_REDUCTION_EXTRA    = (1 << 4)
+  GST_PHOTOGRAPHY_NOISE_REDUCTION_BAYER = ( 1<<0 ),
+  GST_PHOTOGRAPHY_NOISE_REDUCTION_YCC = ( 1<<1 ),
+  GST_PHOTOGRAPHY_NOISE_REDUCTION_TEMPORAL= ( 1<< 2),
+  GST_PHOTOGRAPHY_NOISE_REDUCTION_FIXED = (1 << 3),
+  GST_PHOTOGRAPHY_NOISE_REDUCTION_EXTRA = (1 << 4)
 } GstPhotographyNoiseReduction;
 
 /**
@@ -179,8 +181,6 @@ typedef enum
  * @GST_PHOTOGRAPHY_WB_MODE_FLUORESCENT: Mode for fluorescent lighting
  * @GST_PHOTOGRAPHY_WB_MODE_MANUAL: Disable automatic white balance adjustment
  * and keep current values.
- * @GST_PHOTOGRAPHY_WB_MODE_WARM_FLUORESCENT: Mode for warm fluorescent lighting (Since: 1.2)
- * @GST_PHOTOGRAPHY_WB_MODE_SHADE: Mode for shade lighting (Since: 1.2)
  *
  * Modes for white balance control.
  */
@@ -192,9 +192,7 @@ typedef enum
   GST_PHOTOGRAPHY_WB_MODE_SUNSET,
   GST_PHOTOGRAPHY_WB_MODE_TUNGSTEN,
   GST_PHOTOGRAPHY_WB_MODE_FLUORESCENT,
-  GST_PHOTOGRAPHY_WB_MODE_MANUAL,
-  GST_PHOTOGRAPHY_WB_MODE_WARM_FLUORESCENT,
-  GST_PHOTOGRAPHY_WB_MODE_SHADE
+  GST_PHOTOGRAPHY_WB_MODE_MANUAL
 } GstPhotographyWhiteBalanceMode;
 
 /**
@@ -211,10 +209,6 @@ typedef enum
  * @GST_PHOTOGRAPHY_COLOR_TONE_MODE_SKY_BLUE: Sky blue
  * @GST_PHOTOGRAPHY_COLOR_TONE_MODE_GRASS_GREEN: Grass green
  * @GST_PHOTOGRAPHY_COLOR_TONE_MODE_SKIN_WHITEN: Skin whiten
- * @GST_PHOTOGRAPHY_COLOR_TONE_MODE_POSTERIZE: Posterize (Since: 1.2)
- * @GST_PHOTOGRAPHY_COLOR_TONE_MODE_WHITEBOARD: Whiteboard (Since: 1.2)
- * @GST_PHOTOGRAPHY_COLOR_TONE_MODE_BLACKBOARD: Blackboard (Since: 1.2)
- * @GST_PHOTOGRAPHY_COLOR_TONE_MODE_AQUA: Aqua (Since: 1.2)
  *
  * Modes for special color effects.
  */
@@ -231,11 +225,7 @@ typedef enum
   GST_PHOTOGRAPHY_COLOR_TONE_MODE_OUT_OF_FOCUS,
   GST_PHOTOGRAPHY_COLOR_TONE_MODE_SKY_BLUE,
   GST_PHOTOGRAPHY_COLOR_TONE_MODE_GRASS_GREEN,
-  GST_PHOTOGRAPHY_COLOR_TONE_MODE_SKIN_WHITEN,
-  GST_PHOTOGRAPHY_COLOR_TONE_MODE_POSTERIZE,
-  GST_PHOTOGRAPHY_COLOR_TONE_MODE_WHITEBOARD,
-  GST_PHOTOGRAPHY_COLOR_TONE_MODE_BLACKBOARD,
-  GST_PHOTOGRAPHY_COLOR_TONE_MODE_AQUA
+  GST_PHOTOGRAPHY_COLOR_TONE_MODE_SKIN_WHITEN
 } GstPhotographyColorToneMode;
 
 /**
@@ -247,23 +237,6 @@ typedef enum
  * @GST_PHOTOGRAPHY_SCENE_MODE_SPORT: Mode for scene with fast motion
  * @GST_PHOTOGRAPHY_SCENE_MODE_NIGHT: Mode for night conditions
  * @GST_PHOTOGRAPHY_SCENE_MODE_AUTO: Choose scene mode automatically
- * @GST_PHOTOGRAPHY_SCENE_MODE_ACTION: Take photos of fast moving
- *     objects (Since: 1.2)
- * @GST_PHOTOGRAPHY_SCENE_MODE_NIGHT_PORTRAIT: Take people pictures
- *     at night (Since: 1.2)
- * @GST_PHOTOGRAPHY_SCENE_MODE_THEATRE: Take photos in a theater (Since: 1.2)
- * @GST_PHOTOGRAPHY_SCENE_MODE_BEACH: Take pictures on the beach (Since: 1.2)
- * @GST_PHOTOGRAPHY_SCENE_MODE_SNOW: Take pictures on the snow (Since: 1.2)
- * @GST_PHOTOGRAPHY_SCENE_MODE_SUNSET: Take sunset photos (Since: 1.2)
- * @GST_PHOTOGRAPHY_SCENE_MODE_STEADY_PHOTO: Avoid blurry pictures
- *     (for example, due to hand shake) (Since: 1.2)
- * @GST_PHOTOGRAPHY_SCENE_MODE_FIREWORKS: For shooting firework
- *     displays (Since: 1.2)
- * @GST_PHOTOGRAPHY_SCENE_MODE_PARTY: Take indoor low-light shot (Since: 1.2)
- * @GST_PHOTOGRAPHY_SCENE_MODE_CANDLELIGHT: Capture the naturally warm color
- *     of scenes lit by candles (Since: 1.2)
- * @GST_PHOTOGRAPHY_SCENE_MODE_BARCODE: Applications are looking for
- *     a barcode (Since: 1.2)
  *
  * Each mode contains preset #GstPhotography options in order to produce
  * good capturing result in certain scene.
@@ -276,18 +249,7 @@ typedef enum
   GST_PHOTOGRAPHY_SCENE_MODE_LANDSCAPE,
   GST_PHOTOGRAPHY_SCENE_MODE_SPORT,
   GST_PHOTOGRAPHY_SCENE_MODE_NIGHT,
-  GST_PHOTOGRAPHY_SCENE_MODE_AUTO,
-  GST_PHOTOGRAPHY_SCENE_MODE_ACTION,
-  GST_PHOTOGRAPHY_SCENE_MODE_NIGHT_PORTRAIT,
-  GST_PHOTOGRAPHY_SCENE_MODE_THEATRE,
-  GST_PHOTOGRAPHY_SCENE_MODE_BEACH,
-  GST_PHOTOGRAPHY_SCENE_MODE_SNOW,
-  GST_PHOTOGRAPHY_SCENE_MODE_SUNSET,
-  GST_PHOTOGRAPHY_SCENE_MODE_STEADY_PHOTO,
-  GST_PHOTOGRAPHY_SCENE_MODE_FIREWORKS,
-  GST_PHOTOGRAPHY_SCENE_MODE_PARTY,
-  GST_PHOTOGRAPHY_SCENE_MODE_CANDLELIGHT,
-  GST_PHOTOGRAPHY_SCENE_MODE_BARCODE
+  GST_PHOTOGRAPHY_SCENE_MODE_AUTO
 } GstPhotographySceneMode;
 
 /**
@@ -337,22 +299,22 @@ typedef enum
  */
 typedef enum
 {
-  GST_PHOTOGRAPHY_CAPS_NONE              = (0 << 0),
-  GST_PHOTOGRAPHY_CAPS_EV_COMP           = (1 << 0),
-  GST_PHOTOGRAPHY_CAPS_ISO_SPEED         = (1 << 1),
-  GST_PHOTOGRAPHY_CAPS_WB_MODE           = (1 << 2),
-  GST_PHOTOGRAPHY_CAPS_TONE              = (1 << 3),
-  GST_PHOTOGRAPHY_CAPS_SCENE             = (1 << 4),
-  GST_PHOTOGRAPHY_CAPS_FLASH             = (1 << 5),
-  GST_PHOTOGRAPHY_CAPS_ZOOM              = (1 << 6),
-  GST_PHOTOGRAPHY_CAPS_FOCUS             = (1 << 7),
-  GST_PHOTOGRAPHY_CAPS_APERTURE          = (1 << 8),
-  GST_PHOTOGRAPHY_CAPS_EXPOSURE          = (1 << 9),
-  GST_PHOTOGRAPHY_CAPS_SHAKE             = (1 << 10),
-  GST_PHOTOGRAPHY_CAPS_WHITE_BALANCE     = (1 << 11),
-  GST_PHOTOGRAPHY_CAPS_NOISE_REDUCTION   = (1 << 12),
+  GST_PHOTOGRAPHY_CAPS_NONE = (0 << 0),
+  GST_PHOTOGRAPHY_CAPS_EV_COMP = (1 << 0),
+  GST_PHOTOGRAPHY_CAPS_ISO_SPEED = (1 << 1),
+  GST_PHOTOGRAPHY_CAPS_WB_MODE = (1 << 2),
+  GST_PHOTOGRAPHY_CAPS_TONE = (1 << 3),
+  GST_PHOTOGRAPHY_CAPS_SCENE = (1 << 4),
+  GST_PHOTOGRAPHY_CAPS_FLASH = (1 << 5),
+  GST_PHOTOGRAPHY_CAPS_ZOOM = (1 << 6),
+  GST_PHOTOGRAPHY_CAPS_FOCUS = (1 << 7),
+  GST_PHOTOGRAPHY_CAPS_APERTURE = (1 << 8),
+  GST_PHOTOGRAPHY_CAPS_EXPOSURE = (1 << 9),
+  GST_PHOTOGRAPHY_CAPS_SHAKE = (1 << 10),
+  GST_PHOTOGRAPHY_CAPS_WHITE_BALANCE = (1 << 11),
+  GST_PHOTOGRAPHY_CAPS_NOISE_REDUCTION = (1 << 12),
   GST_PHOTOGRAPHY_CAPS_FLICKER_REDUCTION = (1 << 13),
-  GST_PHOTOGRAPHY_CAPS_ALL               = (~0)
+  GST_PHOTOGRAPHY_CAPS_ALL = (~0)
 } GstPhotographyCaps;
 
 /**
@@ -457,7 +419,6 @@ typedef struct
   gfloat lens_focus;
   guint min_exposure_time;
   guint max_exposure_time;
-  /* FIXME: add padding? */
 } GstPhotographySettings;
 
 /**
@@ -471,7 +432,8 @@ typedef struct
  * will be of @configured_caps format, so this callback allows the application
  * to e.g. reconfigure capsfilters in pipeline if any.
  */
-typedef void (*GstPhotographyCapturePrepared) (gpointer data, const GstCaps *configured_caps);
+typedef void (*GstPhotographyCapturePrepared) (gpointer data,
+    const GstCaps *configured_caps);
 
 /**
  * GstPhotographyInterface:
@@ -510,163 +472,118 @@ typedef struct _GstPhotographyInterface
   GTypeInterface parent;
 
   /* virtual functions */
-  gboolean (*get_ev_compensation)    (GstPhotography * photo, gfloat * ev_comp);
-  gboolean (*get_iso_speed)          (GstPhotography * photo, guint * iso_speed);
-  gboolean (*get_aperture)           (GstPhotography * photo, guint * aperture);
-  gboolean (*get_exposure)           (GstPhotography * photo, guint32 * exposure);
-  gboolean (*get_white_balance_mode) (GstPhotography * photo, GstPhotographyWhiteBalanceMode * wb_mode);
-  gboolean (*get_color_tone_mode)    (GstPhotography * photo, GstPhotographyColorToneMode * tone_mode);
-  gboolean (*get_scene_mode)         (GstPhotography * photo, GstPhotographySceneMode * scene_mode);
-  gboolean (*get_flash_mode)         (GstPhotography * photo, GstPhotographyFlashMode * flash_mode);
-  gboolean (*get_zoom)               (GstPhotography * photo, gfloat * zoom);
-  gboolean (*get_flicker_mode)       (GstPhotography * photo, GstPhotographyFlickerReductionMode * flicker_mode);
-  gboolean (*get_focus_mode)         (GstPhotography * photo, GstPhotographyFocusMode * focus_mode);
+  gboolean (*get_ev_compensation) (GstPhotography * photo, gfloat * ev_comp);
+  gboolean (*get_iso_speed) (GstPhotography * photo, guint * iso_speed);
+  gboolean (*get_aperture) (GstPhotography * photo, guint * aperture);
+  gboolean (*get_exposure) (GstPhotography * photo, guint32 * exposure);
+  gboolean (*get_white_balance_mode) (GstPhotography * photo,
+    GstPhotographyWhiteBalanceMode * wb_mode);
+  gboolean (*get_color_tone_mode) (GstPhotography * photo,
+    GstPhotographyColorToneMode * tone_mode);
+  gboolean (*get_scene_mode) (GstPhotography * photo,
+    GstPhotographySceneMode * scene_mode);
+  gboolean (*get_flash_mode) (GstPhotography * photo,
+    GstPhotographyFlashMode * flash_mode);
+  gboolean (*get_zoom) (GstPhotography * photo, gfloat * zoom);
+    gboolean (*get_flicker_mode) (GstPhotography * photo,
+    GstPhotographyFlickerReductionMode * flicker_mode);
+  gboolean (*get_focus_mode) (GstPhotography * photo,
+    GstPhotographyFocusMode * focus_mode);
 
-  gboolean (*set_ev_compensation)    (GstPhotography * photo, gfloat ev_comp);
-  gboolean (*set_iso_speed)          (GstPhotography * photo, guint iso_speed);
-  gboolean (*set_aperture)           (GstPhotography * photo, guint aperture);
-  gboolean (*set_exposure)           (GstPhotography * photo, guint32 exposure);
-  gboolean (*set_white_balance_mode) (GstPhotography * photo, GstPhotographyWhiteBalanceMode wb_mode);
-  gboolean (*set_color_tone_mode)    (GstPhotography * photo, GstPhotographyColorToneMode tone_mode);
-  gboolean (*set_scene_mode)         (GstPhotography * photo, GstPhotographySceneMode scene_mode);
-  gboolean (*set_flash_mode)         (GstPhotography * photo, GstPhotographyFlashMode flash_mode);
-  gboolean (*set_zoom)               (GstPhotography * photo, gfloat zoom);
-  gboolean (*set_flicker_mode)       (GstPhotography * photo, GstPhotographyFlickerReductionMode flicker_mode);
-  gboolean (*set_focus_mode)         (GstPhotography * photo, GstPhotographyFocusMode focus_mode);
+  gboolean (*set_ev_compensation) (GstPhotography * photo, gfloat ev_comp);
+  gboolean (*set_iso_speed) (GstPhotography * photo, guint iso_speed);
+  gboolean (*set_aperture) (GstPhotography * photo, guint aperture);
+  gboolean (*set_exposure) (GstPhotography * photo, guint32 exposure);
+  gboolean (*set_white_balance_mode) (GstPhotography * photo,
+    GstPhotographyWhiteBalanceMode wb_mode);
+  gboolean (*set_color_tone_mode) (GstPhotography * photo,
+    GstPhotographyColorToneMode tone_mode);
+  gboolean (*set_scene_mode) (GstPhotography * photo,
+    GstPhotographySceneMode scene_mode);
+  gboolean (*set_flash_mode) (GstPhotography * photo,
+    GstPhotographyFlashMode flash_mode);
+  gboolean (*set_zoom) (GstPhotography * photo, gfloat zoom);
+  gboolean (*set_flicker_mode) (GstPhotography * photo,
+    GstPhotographyFlickerReductionMode flicker_mode);
+  gboolean (*set_focus_mode) (GstPhotography * photo,
+    GstPhotographyFocusMode focus_mode);
 
   GstPhotographyCaps (*get_capabilities) (GstPhotography * photo);
+  gboolean (*prepare_for_capture) (GstPhotography * photo,
+    GstPhotographyCapturePrepared func, GstCaps *capture_caps, gpointer user_data);
+  void (*set_autofocus) (GstPhotography * photo, gboolean on);
+  gboolean (*set_config) (GstPhotography * photo, GstPhotographySettings * config);
+  gboolean (*get_config) (GstPhotography * photo, GstPhotographySettings * config);
 
-  gboolean (*prepare_for_capture)    (GstPhotography * photo, GstPhotographyCapturePrepared func, GstCaps *capture_caps, gpointer user_data);
+  gboolean (*get_noise_reduction) (GstPhotography * photo,
+    GstPhotographyNoiseReduction * noise_reduction);
+  gboolean (*set_noise_reduction) (GstPhotography * photo,
+    GstPhotographyNoiseReduction noise_reduction);
 
-  void     (*set_autofocus)          (GstPhotography * photo, gboolean on);
-
-  gboolean (*set_config)             (GstPhotography * photo, GstPhotographySettings * config);
-  gboolean (*get_config)             (GstPhotography * photo, GstPhotographySettings * config);
-
-  gboolean (*get_noise_reduction)    (GstPhotography * photo, GstPhotographyNoiseReduction * noise_reduction);
-  gboolean (*set_noise_reduction)    (GstPhotography * photo, GstPhotographyNoiseReduction noise_reduction);
-
-  /* FIXME: remove padding, not needed for interfaces */
   /*< private > */
   gpointer _gst_reserved[GST_PADDING];
 } GstPhotographyInterface;
 
-GST_PHOTOGRAPHY_API
 GType gst_photography_get_type (void);
 
 /* virtual class function wrappers */
-
-GST_PHOTOGRAPHY_API
 gboolean gst_photography_get_ev_compensation (GstPhotography * photo,
-                                              gfloat * ev_comp);
-
-GST_PHOTOGRAPHY_API
-gboolean gst_photography_get_iso_speed       (GstPhotography * photo,
-                                              guint * iso_speed);
-
-GST_PHOTOGRAPHY_API
-gboolean gst_photography_get_aperture        (GstPhotography * photo,
-                                              guint * aperture);
-
-GST_PHOTOGRAPHY_API
-gboolean gst_photography_get_exposure        (GstPhotography * photo,
-                                              guint32 * exposure);
-
-GST_PHOTOGRAPHY_API
+    gfloat * ev_comp);
+gboolean gst_photography_get_iso_speed (GstPhotography * photo,
+    guint * iso_speed);
+gboolean gst_photography_get_aperture (GstPhotography * photo,
+    guint * aperture);
+gboolean gst_photography_get_exposure (GstPhotography * photo,
+    guint32 * exposure);
 gboolean gst_photography_get_white_balance_mode (GstPhotography * photo,
-                                                 GstPhotographyWhiteBalanceMode * wb_mode);
-
-GST_PHOTOGRAPHY_API
+    GstPhotographyWhiteBalanceMode * wb_mode);
 gboolean gst_photography_get_color_tone_mode (GstPhotography * photo,
-                                              GstPhotographyColorToneMode * tone_mode);
-
-GST_PHOTOGRAPHY_API
-gboolean gst_photography_get_scene_mode      (GstPhotography * photo,
-                                              GstPhotographySceneMode * scene_mode);
-
-GST_PHOTOGRAPHY_API
-gboolean gst_photography_get_flash_mode      (GstPhotography * photo,
-                                              GstPhotographyFlashMode * flash_mode);
-
-GST_PHOTOGRAPHY_API
+    GstPhotographyColorToneMode * tone_mode);
+gboolean gst_photography_get_scene_mode (GstPhotography * photo,
+    GstPhotographySceneMode * scene_mode);
+gboolean gst_photography_get_flash_mode (GstPhotography * photo,
+    GstPhotographyFlashMode * flash_mode);
 gboolean gst_photography_get_noise_reduction (GstPhotography * photo,
-                                              GstPhotographyNoiseReduction * noise_reduction);
+    GstPhotographyNoiseReduction * noise_reduction);
+gboolean gst_photography_get_zoom (GstPhotography * photo, gfloat * zoom);
+gboolean gst_photography_get_flicker_mode (GstPhotography * photo,
+    GstPhotographyFlickerReductionMode *mode);
+gboolean gst_photography_get_focus_mode (GstPhotography * photo,
+    GstPhotographyFocusMode *mode);
 
-GST_PHOTOGRAPHY_API
-gboolean gst_photography_get_zoom            (GstPhotography * photo, gfloat * zoom);
-
-GST_PHOTOGRAPHY_API
-gboolean gst_photography_get_flicker_mode    (GstPhotography * photo,
-                                              GstPhotographyFlickerReductionMode * mode);
-
-GST_PHOTOGRAPHY_API
-gboolean gst_photography_get_focus_mode      (GstPhotography * photo,
-                                              GstPhotographyFocusMode * mode);
-
-GST_PHOTOGRAPHY_API
 gboolean gst_photography_set_ev_compensation (GstPhotography * photo,
-                                              gfloat ev_comp);
-
-GST_PHOTOGRAPHY_API
-gboolean gst_photography_set_iso_speed       (GstPhotography * photo,
-                                              guint iso_speed);
-
-GST_PHOTOGRAPHY_API
-gboolean gst_photography_set_aperture        (GstPhotography * photo, guint aperture);
-
-GST_PHOTOGRAPHY_API
-gboolean gst_photography_set_exposure        (GstPhotography * photo, guint exposure);
-
-GST_PHOTOGRAPHY_API
+    gfloat ev_comp);
+gboolean gst_photography_set_iso_speed (GstPhotography * photo,
+    guint iso_speed);
+gboolean gst_photography_set_aperture (GstPhotography * photo, guint aperture);
+gboolean gst_photography_set_exposure (GstPhotography * photo, guint exposure);
 gboolean gst_photography_set_white_balance_mode (GstPhotography * photo,
-                                                 GstPhotographyWhiteBalanceMode wb_mode);
-
-GST_PHOTOGRAPHY_API
+    GstPhotographyWhiteBalanceMode wb_mode);
 gboolean gst_photography_set_color_tone_mode (GstPhotography * photo,
-                                              GstPhotographyColorToneMode tone_mode);
-
-GST_PHOTOGRAPHY_API
-gboolean gst_photography_set_scene_mode      (GstPhotography * photo,
-                                              GstPhotographySceneMode scene_mode);
-
-GST_PHOTOGRAPHY_API
-gboolean gst_photography_set_flash_mode      (GstPhotography * photo,
-                                              GstPhotographyFlashMode flash_mode);
-
-GST_PHOTOGRAPHY_API
+    GstPhotographyColorToneMode tone_mode);
+gboolean gst_photography_set_scene_mode (GstPhotography * photo,
+    GstPhotographySceneMode scene_mode);
+gboolean gst_photography_set_flash_mode (GstPhotography * photo,
+    GstPhotographyFlashMode flash_mode);
 gboolean gst_photography_set_noise_reduction (GstPhotography * photo,
-                                              GstPhotographyNoiseReduction noise_reduction);
+    GstPhotographyNoiseReduction noise_reduction);
+gboolean gst_photography_set_zoom (GstPhotography * photo, gfloat zoom);
+gboolean gst_photography_set_flicker_mode (GstPhotography * photo,
+    GstPhotographyFlickerReductionMode mode);
+gboolean gst_photography_set_focus_mode (GstPhotography * photo,
+    GstPhotographyFocusMode mode);
 
-GST_PHOTOGRAPHY_API
-gboolean gst_photography_set_zoom            (GstPhotography * photo, gfloat zoom);
-
-GST_PHOTOGRAPHY_API
-gboolean gst_photography_set_flicker_mode    (GstPhotography * photo,
-                                              GstPhotographyFlickerReductionMode mode);
-
-GST_PHOTOGRAPHY_API
-gboolean gst_photography_set_focus_mode      (GstPhotography * photo,
-                                              GstPhotographyFocusMode mode);
-
-GST_PHOTOGRAPHY_API
 GstPhotographyCaps gst_photography_get_capabilities (GstPhotography * photo);
 
-GST_PHOTOGRAPHY_API
 gboolean gst_photography_prepare_for_capture (GstPhotography * photo,
-                                              GstPhotographyCapturePrepared func,
-                                              GstCaps *capture_caps,
-                                              gpointer user_data);
+    GstPhotographyCapturePrepared func, GstCaps *capture_caps, gpointer user_data);
 
-GST_PHOTOGRAPHY_API
-gboolean gst_photography_set_config    (GstPhotography         * photo,
-                                        GstPhotographySettings * config);
+void gst_photography_set_autofocus (GstPhotography * photo, gboolean on);
 
-GST_PHOTOGRAPHY_API
-gboolean gst_photography_get_config    (GstPhotography         * photo,
-                                        GstPhotographySettings * config);
-
-GST_PHOTOGRAPHY_API
-void     gst_photography_set_autofocus (GstPhotography * photo, gboolean on);
+gboolean gst_photography_set_config (GstPhotography * photo,
+    GstPhotographySettings * config);
+gboolean gst_photography_get_config (GstPhotography * photo,
+    GstPhotographySettings * config);
 
 G_END_DECLS
 
