@@ -13,8 +13,8 @@
  *
  * You should have received a copy of the GNU Library General Public
  * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 51 Franklin St, Fifth Floor,
- * Boston, MA 02110-1301, USA.
+ * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
+ * Boston, MA 02111-1307, USA.
  */
 
 #ifdef HAVE_CONFIG_H
@@ -100,18 +100,7 @@ gst_geometric_transform_generate_map (GstGeometricTransform * gt)
   /*
    * (x,y) pairs of the inverse mapping
    */
-  gsize map_size;
-
-  /* Use GLib's checked multiplication to prevent overflow */
-  if (!g_size_checked_mul (&map_size, gt->width, gt->height) ||
-      !g_size_checked_mul (&map_size, map_size, 2) ||
-      !g_size_checked_mul (&map_size, map_size, sizeof (gdouble))) {
-    GST_ERROR_OBJECT (gt,
-        "Image dimensions too large, map allocation would overflow");
-    return FALSE;
-  }
-
-  gt->map = g_malloc0 (map_size);
+  gt->map = g_malloc0 (sizeof (gdouble) * gt->width * gt->height * 2);
   ptr = gt->map;
 
   for (y = 0; y < gt->height; y++) {
@@ -192,8 +181,8 @@ gst_geometric_transform_do_map (GstGeometricTransform * gt, guint8 * in_data,
       break;
 
     case GST_GT_OFF_EDGES_PIXELS_WRAP:
-      in_x = gst_gm_mod_float (in_x, gt->width);
-      in_y = gst_gm_mod_float (in_y, gt->height);
+      in_x = mod_float (in_x, gt->width);
+      in_y = mod_float (in_y, gt->height);
       if (in_x < 0)
         in_x += gt->width;
       if (in_y < 0)
@@ -240,7 +229,7 @@ gst_geometric_transform_transform_frame (GstVideoFilter * vfilter,
 {
   GstGeometricTransform *gt;
   GstGeometricTransformClass *klass;
-  gint x, y, i;
+  gint x, y;
   GstFlowReturn ret = GST_FLOW_OK;
   gdouble *ptr;
   guint8 *in_data;
@@ -251,16 +240,7 @@ gst_geometric_transform_transform_frame (GstVideoFilter * vfilter,
 
   in_data = GST_VIDEO_FRAME_PLANE_DATA (in_frame, 0);
   out_data = GST_VIDEO_FRAME_PLANE_DATA (out_frame, 0);
-
-  if (GST_VIDEO_FRAME_FORMAT (out_frame) == GST_VIDEO_FORMAT_AYUV) {
-    /* in AYUV black is not just all zeros:
-     * 0x10 is black for Y,
-     * 0x80 is black for Cr and Cb */
-    for (i = 0; i < out_frame->map[0].size; i += 4)
-      GST_WRITE_UINT32_BE (out_data + i, 0xff108080);
-  } else {
-    memset (out_data, 0, out_frame->map[0].size);
-  }
+  memset (out_data, 0, out_frame->map[0].size);
 
   GST_OBJECT_LOCK (gt);
   if (gt->precalc_map) {
@@ -363,10 +343,10 @@ gst_geometric_transform_base_init (gpointer g_class)
 {
   GstElementClass *element_class = GST_ELEMENT_CLASS (g_class);
 
-  gst_element_class_add_static_pad_template (element_class,
-      &gst_geometric_transform_sink_template);
-  gst_element_class_add_static_pad_template (element_class,
-      &gst_geometric_transform_src_template);
+  gst_element_class_add_pad_template (element_class,
+      gst_static_pad_template_get (&gst_geometric_transform_sink_template));
+  gst_element_class_add_pad_template (element_class,
+      gst_static_pad_template_get (&gst_geometric_transform_src_template));
 }
 
 static void
@@ -382,8 +362,10 @@ gst_geometric_transform_class_init (gpointer klass, gpointer class_data)
 
   parent_class = g_type_class_peek_parent (klass);
 
-  obj_class->set_property = gst_geometric_transform_set_property;
-  obj_class->get_property = gst_geometric_transform_get_property;
+  obj_class->set_property =
+      GST_DEBUG_FUNCPTR (gst_geometric_transform_set_property);
+  obj_class->get_property =
+      GST_DEBUG_FUNCPTR (gst_geometric_transform_get_property);
 
   trans_class->stop = GST_DEBUG_FUNCPTR (gst_geometric_transform_stop);
   trans_class->before_transform =
@@ -399,9 +381,6 @@ gst_geometric_transform_class_init (gpointer klass, gpointer class_data)
           "What to do with off edge pixels",
           GST_GT_OFF_EDGES_PIXELS_METHOD_TYPE, DEFAULT_OFF_EDGE_PIXELS,
           GST_PARAM_CONTROLLABLE | G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS));
-
-  gst_type_mark_as_plugin_api (GST_GT_OFF_EDGES_PIXELS_METHOD_TYPE, 0);
-  gst_type_mark_as_plugin_api (GST_TYPE_GEOMETRIC_TRANSFORM, 0);
 }
 
 static void
