@@ -15,24 +15,12 @@
  *
  * You should have received a copy of the GNU Library General Public
  * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 51 Franklin St, Fifth Floor,
- * Boston, MA 02110-1301, USA.
+ * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
+ * Boston, MA 02111-1307, USA.
  */
 
-#include <gst/video/video-format.h>
-
 #include "gstdshow.h"
 #include "gstdshowfakesink.h"
-#include "gstdshowvideosrc.h"
-
-GST_DEBUG_CATEGORY_EXTERN (dshowsrcwrapper_debug);
-#define GST_CAT_DEFAULT dshowsrcwrapper_debug
-
-gchar *
-wchar_to_gchar (WCHAR * w)
-{
-  return g_utf16_to_utf8 ((const gunichar2 *) w, wcslen (w), NULL, NULL, NULL);
-}
 
 const GUID MEDIASUBTYPE_I420
     = { 0x30323449, 0x0000, 0x0010, {0x80, 0x00, 0x00, 0xAA, 0x00, 0x38, 0x9B,
@@ -49,7 +37,7 @@ gst_dshow_free_mediatype (AM_MEDIA_TYPE * pmt)
       pmt->pbFormat = NULL;
     }
     if (pmt->pUnk != NULL) {
-      /* Unnecessary because pUnk should not be used, but safest. */
+      /* Unecessary because pUnk should not be used, but safest. */
       pmt->pUnk->Release ();
       pmt->pUnk = NULL;
     }
@@ -135,8 +123,10 @@ gst_dshow_new_pin_mediatype_from_streamcaps (IPin * pin, gint id, IAMStreamConfi
 void
 gst_dshow_free_pins_mediatypes (GList * pins_mediatypes)
 {
-  g_list_free_full (pins_mediatypes,
-      (GDestroyNotify) gst_dshow_free_pin_mediatype);
+  while (pins_mediatypes != NULL) {
+    gst_dshow_free_pin_mediatype (pins_mediatypes->data);
+    pins_mediatypes = g_list_remove_link (pins_mediatypes, pins_mediatypes);
+  }
 }
 
 gboolean
@@ -205,7 +195,7 @@ gst_dshow_find_filter (CLSID input_majortype, CLSID input_subtype,
   if (filter)
     *filter = NULL;
 
-  /* create a private copy of preferred filter substring in upper case */
+  /* create a private copy of prefered filter substring in upper case */
   if (prefered_filter_name) {
     prefered_filter_upper = g_strdup (prefered_filter_name);
     _strupr (prefered_filter_upper);
@@ -245,7 +235,9 @@ gst_dshow_find_filter (CLSID input_majortype, CLSID input_subtype,
 
       hres = property_bag->Read (L"FriendlyName", &varFriendlyName, NULL);
       if (hres == S_OK && varFriendlyName.bstrVal) {
-        friendly_name = wchar_to_gchar (varFriendlyName.bstrVal);
+        friendly_name =
+            g_utf16_to_utf8 ((const gunichar2 *) varFriendlyName.bstrVal,
+            wcslen (varFriendlyName.bstrVal), NULL, NULL, NULL);
         if (friendly_name)
           _strupr (friendly_name);
         SysFreeString (varFriendlyName.bstrVal);
@@ -279,12 +271,14 @@ gst_dshow_find_filter (CLSID input_majortype, CLSID input_subtype,
       filter_temp->Release ();
     }
 
-    g_free (friendly_name);
+    if (friendly_name)
+      g_free (friendly_name);
     moniker->Release ();
   }
 
 clean:
-  g_free (prefered_filter_upper);
+  if (prefered_filter_upper)
+    g_free (prefered_filter_upper);
   if (enum_moniker)
     enum_moniker->Release ();
   if (mapper)
@@ -293,200 +287,10 @@ clean:
   return ret;
 }
 
-void
-gst_dshow_device_entry_free (DshowDeviceEntry * entry)
-{
-  if (entry) {
-    g_free (entry->device);
-    entry->device = NULL;
-    g_free (entry->device_name);
-    entry->device_name = NULL;
-    if (entry->caps) {
-      gst_caps_unref (entry->caps);
-      entry->caps = NULL;
-    }
-    if (entry->moniker) {
-      entry->moniker->Release ();
-      entry->moniker = NULL;
-    }
-  }
-}
-
-void
-gst_dshow_device_list_free (GList * devices)
-{
-  GList *cur;
-
-  for (cur = devices; cur != NULL; cur = cur->next)
-    gst_dshow_device_entry_free ((DshowDeviceEntry *) cur->data);
-
-  g_list_free (devices);
-}
-
-GList *
-gst_dshow_enumerate_devices (const GUID * device_category, gboolean getcaps)
-{
-  GList *result = NULL;
-  ICreateDevEnum *devices_enum = NULL;
-  IEnumMoniker *enum_moniker = NULL;
-  IMoniker *moniker = NULL;
-  HRESULT hres = S_FALSE;
-  ULONG fetched;
-  gint devidx = -1;
-
-  hres = CoCreateInstance (CLSID_SystemDeviceEnum, NULL, CLSCTX_INPROC_SERVER,
-      IID_ICreateDevEnum, (void **) &devices_enum);
-  if (hres != S_OK) {
-    GST_ERROR ("Failed to create System Device Enumerator");
-    goto clean;
-  }
-
-  hres = devices_enum->CreateClassEnumerator (*device_category,
-      &enum_moniker, 0);
-  if (hres != S_OK || !enum_moniker) {
-    GST_ERROR ("Failed to create audio/video class device enumerator");
-    goto clean;
-  }
-
-  enum_moniker->Reset ();
-
-  while (enum_moniker->Next (1, &moniker, &fetched) == S_OK) {
-    IPropertyBag *property_bag = NULL;
-    hres = moniker->BindToStorage (NULL, NULL, IID_IPropertyBag,
-        (void **) &property_bag);
-    if (SUCCEEDED (hres) && property_bag) {
-      VARIANT varFriendlyName;
-      VariantInit (&varFriendlyName);
-
-      hres = property_bag->Read (L"FriendlyName", &varFriendlyName, NULL);
-      if (hres == S_OK && varFriendlyName.bstrVal) {
-        gchar *friendly_name = wchar_to_gchar (varFriendlyName.bstrVal);
-
-        devidx++;
-        GST_DEBUG ("Found device idx=%d: device-name='%s'",
-            devidx, friendly_name);
-
-        WCHAR *wszDisplayName = NULL;
-        hres = moniker->GetDisplayName (NULL, NULL, &wszDisplayName);
-        if (hres == S_OK && wszDisplayName) {
-          DshowDeviceEntry *entry = g_new0 (DshowDeviceEntry, 1);
-          gchar *device_path = NULL;
-          GstCaps *caps = NULL;
-
-          device_path = wchar_to_gchar (wszDisplayName);
-          CoTaskMemFree (wszDisplayName);
-
-          /* getting caps can be slow, so make it optional when enumerating */
-          if (getcaps) {
-            IBindCtx *lpbc = NULL;
-            hres = CreateBindCtx (0, &lpbc);
-            if (SUCCEEDED (hres)) {
-              IBaseFilter *video_cap_filter = NULL;
-              hres = moniker->BindToObject (lpbc, NULL, IID_IBaseFilter,
-                (LPVOID *) & video_cap_filter);
-              if (video_cap_filter) {
-                caps = gst_dshowvideosrc_getcaps_from_capture_filter (video_cap_filter, NULL);
-                video_cap_filter->Release ();
-              }
-              lpbc->Release ();
-            }
-          }
-
-          entry->device = device_path;
-          entry->device_name = friendly_name;
-          entry->device_index = devidx;
-          entry->caps = caps;
-          entry->moniker = moniker;
-          moniker = NULL;
-          result = g_list_append (result, entry);
-        } else {
-          g_free (friendly_name);
-        }
-        SysFreeString (varFriendlyName.bstrVal);
-      }
-      property_bag->Release ();
-    }
-    if (moniker) {
-      moniker->Release ();
-    }
-  }
-
-clean:
-  if (enum_moniker) {
-    enum_moniker->Release ();
-  }
-
-  if (devices_enum) {
-    devices_enum->Release ();
-  }
-
-  return result;
-}
-
-DshowDeviceEntry *
-gst_dshow_select_device (const GUID * device_category,
-    const gchar * device, const gchar * device_name, const gint device_index)
-{
-  GList *devices = NULL;
-  GList *item = NULL;
-  DshowDeviceEntry *selected = NULL;
-
-  GST_DEBUG ("Trying to select device-index=%d, device-name='%s', device='%s'",
-    device_index, device_name, device);
-
-  devices = gst_dshow_enumerate_devices (&CLSID_VideoInputDeviceCategory, FALSE);
-
-  for (item = devices; item != NULL; item = item->next) {
-    DshowDeviceEntry *entry = (DshowDeviceEntry *) item->data;
-
-    /* device will be used first, then device-name, then device-index */
-    if (device && g_strcmp0 (device, entry->device) == 0) {
-      selected = entry;
-      break;
-    } else if (!device && device_name && g_strcmp0 (device_name, entry->device_name) == 0) {
-      selected = entry;
-      break;
-    } else if (!device && !device_name && device_index == entry->device_index) {
-      selected = entry;
-      break;
-    }
-  }
-
-  if (selected) {
-    devices = g_list_remove (devices, selected);
-    GST_DEBUG ("Selected device-index=%d, device-name='%s', device='%s'",
-      selected->device_index, selected->device_name, selected->device);
-  } else {
-    GST_DEBUG ("No matching device found");
-  }
-
-  gst_dshow_device_list_free (devices);
-
-  return selected;
-}
-
-IBaseFilter *
-gst_dshow_create_capture_filter (IMoniker *moniker)
-{
-  HRESULT hres = S_OK;
-  IBindCtx *lpbc = NULL;
-  IBaseFilter *video_cap_filter = NULL;
-
-  g_assert (moniker != NULL);
-
-  hres = CreateBindCtx (0, &lpbc);
-  if (SUCCEEDED (hres)) {
-    hres = moniker->BindToObject (lpbc, NULL, IID_IBaseFilter,
-        (LPVOID *) & video_cap_filter);
-    lpbc->Release ();
-  }
-
-  return video_cap_filter;
-}
 
 gchar *
 gst_dshow_getdevice_from_devicename (const GUID * device_category,
-    gchar ** device_name, gint * device_index)
+    gchar ** device_name)
 {
   gchar *ret = NULL;
   ICreateDevEnum *devices_enum = NULL;
@@ -495,19 +299,18 @@ gst_dshow_getdevice_from_devicename (const GUID * device_category,
   HRESULT hres = S_FALSE;
   ULONG fetched;
   gboolean bfound = FALSE;
-  gint devidx = -1;
 
   hres = CoCreateInstance (CLSID_SystemDeviceEnum, NULL, CLSCTX_INPROC_SERVER,
       IID_ICreateDevEnum, (void **) &devices_enum);
   if (hres != S_OK) {
-    GST_ERROR ("Failed to create System Device Enumerator");
+    /*error */
     goto clean;
   }
 
   hres = devices_enum->CreateClassEnumerator (*device_category,
       &enum_moniker, 0);
   if (hres != S_OK || !enum_moniker) {
-    GST_ERROR ("Failed to create audio/video class device enumerator");
+    /*error */
     goto clean;
   }
 
@@ -525,24 +328,20 @@ gst_dshow_getdevice_from_devicename (const GUID * device_category,
 
       hres = property_bag->Read (L"FriendlyName", &varFriendlyName, NULL);
       if (hres == S_OK && varFriendlyName.bstrVal) {
-        gchar *friendly_name = wchar_to_gchar (varFriendlyName.bstrVal);
+        gchar *friendly_name =
+            g_utf16_to_utf8 ((const gunichar2 *) varFriendlyName.bstrVal,
+            wcslen (varFriendlyName.bstrVal), NULL, NULL, NULL);
 
-        devidx++;
-        GST_DEBUG ("Found device idx=%d: device-name='%s'",
-            devidx, friendly_name);
-
-        if ((!*device_name || !**device_name) && devidx == *device_index) {
-          g_free (*device_name);
+        if (!*device_name) {
           *device_name = g_strdup (friendly_name);
         }
 
-        if ((*device_name && **device_name)
-            && _stricmp (*device_name, friendly_name) == 0) {
+        if (_stricmp (*device_name, friendly_name) == 0) {
           WCHAR *wszDisplayName = NULL;
           hres = moniker->GetDisplayName (NULL, NULL, &wszDisplayName);
           if (hres == S_OK && wszDisplayName) {
-            *device_index = devidx;
-            ret = wchar_to_gchar (wszDisplayName);
+            ret = g_utf16_to_utf8 ((const gunichar2 *) wszDisplayName,
+                wcslen (wszDisplayName), NULL, NULL, NULL);
             CoTaskMemFree (wszDisplayName);
           }
           bfound = TRUE;
@@ -606,40 +405,9 @@ gst_dshow_guid_to_gst_video_format (AM_MEDIA_TYPE *mediatype)
   if (gst_dshow_check_mediatype (mediatype, MEDIASUBTYPE_YUY2, FORMAT_VideoInfo))
     return GST_VIDEO_FORMAT_YUY2;
 
-  if (gst_dshow_check_mediatype (mediatype, MEDIASUBTYPE_UYVY, FORMAT_VideoInfo))
-    return GST_VIDEO_FORMAT_UYVY;
-
-  if (gst_dshow_check_mediatype (mediatype, MEDIASUBTYPE_RGB32, FORMAT_VideoInfo))
-    return GST_VIDEO_FORMAT_BGRx;
-
-  if (gst_dshow_check_mediatype (mediatype, MEDIASUBTYPE_RGB565, FORMAT_VideoInfo))
-    return GST_VIDEO_FORMAT_BGR16;
-
-  if (gst_dshow_check_mediatype (mediatype, MEDIASUBTYPE_RGB555, FORMAT_VideoInfo))
-    return GST_VIDEO_FORMAT_BGR15;
-
-  if (gst_dshow_check_mediatype (mediatype, MEDIASUBTYPE_RGB8, FORMAT_VideoInfo))
-    return GST_VIDEO_FORMAT_GRAY8;
-
   return GST_VIDEO_FORMAT_UNKNOWN;
 }
 
-gboolean
-gst_dshow_is_pin_connected (IPin * pin)
-{
-  IPin *tmp_pin = NULL;
-  gboolean res;
-  HRESULT hres;
-
-  g_assert (pin);
-  hres = pin->ConnectedTo (&tmp_pin);
-  res = (hres != VFW_E_NOT_CONNECTED);
-  if (tmp_pin)
-    tmp_pin->Release ();
-
-  return res;
-}
-
 GstCaps *
 gst_dshow_new_video_caps (GstVideoFormat video_format, const gchar * name,
     GstCapturePinMediaType * pin_mediatype)
@@ -653,28 +421,13 @@ gst_dshow_new_video_caps (GstVideoFormat video_format, const gchar * name,
   /* raw video format */
   switch (video_format) {
     case GST_VIDEO_FORMAT_BGR:
-      video_caps = gst_caps_from_string (GST_VIDEO_CAPS_MAKE ("BGR"));
+      video_caps = gst_caps_from_string (GST_VIDEO_CAPS_BGR);
       break;
     case GST_VIDEO_FORMAT_I420:
-      video_caps = gst_caps_from_string (GST_VIDEO_CAPS_MAKE ("I420"));
+      video_caps = gst_caps_from_string (GST_VIDEO_CAPS_YUV ("I420"));
 	  break;
     case GST_VIDEO_FORMAT_YUY2:
-      video_caps = gst_caps_from_string (GST_VIDEO_CAPS_MAKE ("YUY2"));
-      break;
-    case GST_VIDEO_FORMAT_UYVY:
-      video_caps = gst_caps_from_string (GST_VIDEO_CAPS_MAKE ("UYVY"));
-      break;
-    case GST_VIDEO_FORMAT_BGRx:
-      video_caps = gst_caps_from_string (GST_VIDEO_CAPS_MAKE ("BGRx"));
-      break;
-    case GST_VIDEO_FORMAT_BGR16:
-      video_caps = gst_caps_from_string (GST_VIDEO_CAPS_MAKE ("BGR16"));
-      break;
-    case GST_VIDEO_FORMAT_BGR15:
-      video_caps = gst_caps_from_string (GST_VIDEO_CAPS_MAKE ("BGR15"));
-      break;
-    case GST_VIDEO_FORMAT_GRAY8:
-      video_caps = gst_caps_from_string (GST_VIDEO_CAPS_MAKE ("GRAY8"));
+      video_caps = gst_caps_from_string (GST_VIDEO_CAPS_YUV ("YUY2"));
       break;
     default:
       break;
@@ -685,16 +438,12 @@ gst_dshow_new_video_caps (GstVideoFormat video_format, const gchar * name,
     if (g_ascii_strncasecmp (name, "video/x-dv, systemstream=FALSE", 31) == 0) {
       video_caps = gst_caps_new_simple ("video/x-dv",
           "systemstream", G_TYPE_BOOLEAN, FALSE,
-          "format", G_TYPE_STRING, "dvsd",
+          "format", GST_TYPE_FOURCC, GST_MAKE_FOURCC ('d', 'v', 's', 'd'),
           NULL);
     } else if (g_ascii_strncasecmp (name, "video/x-dv, systemstream=TRUE", 31) == 0) {
       video_caps = gst_caps_new_simple ("video/x-dv",
           "systemstream", G_TYPE_BOOLEAN, TRUE, NULL);
       return video_caps;
-    } else if (g_ascii_strncasecmp (name, "image/jpeg", 10) == 0) {
-      video_caps = gst_caps_new_simple ("image/jpeg", NULL);
-    } else if (g_ascii_strncasecmp (name, "video/x-h264", 12) == 0) {
-      video_caps = gst_caps_new_simple ("video/x-h264", NULL);
     }
   }
 
@@ -741,21 +490,3 @@ gst_dshow_new_video_caps (GstVideoFormat video_format, const gchar * name,
 
   return video_caps;
 }
-
-bool gst_dshow_configure_latency (IPin *pCapturePin, guint bufSizeMS)
-{
-  HRESULT hr;
-  ALLOCATOR_PROPERTIES alloc_prop;
-  IAMBufferNegotiation * pNeg = NULL;
-  hr = pCapturePin->QueryInterface(IID_IAMBufferNegotiation, (void **)&pNeg);
-
-  if(!SUCCEEDED (hr))
-    return FALSE;
-
-  alloc_prop.cbAlign = -1;  // -1 means no preference.
-  alloc_prop.cbBuffer = bufSizeMS;
-  alloc_prop.cbPrefix = -1;
-  alloc_prop.cBuffers = -1;
-  hr = pNeg->SuggestAllocatorProperties (&alloc_prop);
-  return SUCCEEDED (hr);
-}
