@@ -38,8 +38,8 @@
  *
  * You should have received a copy of the GNU Library General Public
  * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 51 Franklin St, Fifth Floor,
- * Boston, MA 02110-1301, USA.
+ * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
+ * Boston, MA 02111-1307, USA.
  */
 
 #ifdef HAVE_CONFIG_H
@@ -605,11 +605,11 @@ decompressCb (void *decompressionTrackingRefCon,
 
       /* special copy for stride handling */
       for (i = 0; i < qtwrapper->height; i++)
-        memmove (GST_BUFFER_DATA (outbuf) + realpixels * i,
+        g_memmove (GST_BUFFER_DATA (outbuf) + realpixels * i,
             addr + stride * i, realpixels);
 
     } else
-      memmove (GST_BUFFER_DATA (outbuf), addr, (int) qtwrapper->outsize);
+      g_memmove (GST_BUFFER_DATA (outbuf), addr, (int) qtwrapper->outsize);
 
     /* Release CVPixelBuffer */
     CVPixelBufferUnlockBaseAddress (pixelBuffer, 0);
