@@ -1,6 +1,6 @@
 /*
  * Copyright (C) 2007 Haakon Sporsheim <hakon.sporsheim@tandberg.com>
- *               2008 Ole André Vadla Ravnås <ole.andre.ravnas@tandberg.com>
+ *               2008 Ole Andr Vadla Ravns <ole.andre.ravnas@tandberg.com>
  *               2009 Knut Inge Hvidsten <knut.inge.hvidsten@tandberg.com>
  *
  * This library is free software; you can redistribute it and/or
@@ -15,8 +15,8 @@
  *
  * You should have received a copy of the GNU Library General Public
  * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 51 Franklin St, Fifth Floor,
- * Boston, MA 02110-1301, USA.
+ * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
+ * Boston, MA 02111-1307, USA.
  */
 
 #include "ksvideohelpers.h"
@@ -125,56 +125,95 @@ ks_video_device_list_sort_cameras_first (GList * devices)
 }
 
 static GstStructure *
-ks_video_format_to_structure (GUID subtype_guid, GUID format_guid,
-    gboolean * p_is_rgb)
+ks_video_format_to_structure (GUID subtype_guid, GUID format_guid)
 {
   GstStructure *structure = NULL;
-  const gchar *media_type = NULL, *format = NULL;
-  /* RGB formats can be bottom-up (upside down) DIB */
-  gboolean is_rgb = FALSE;
 
   if (IsEqualGUID (&subtype_guid, &MEDIASUBTYPE_MJPG) || IsEqualGUID (&subtype_guid, &MEDIASUBTYPE_TVMJ) ||     /* FIXME: NOT tested */
       IsEqualGUID (&subtype_guid, &MEDIASUBTYPE_WAKE) ||        /* FIXME: NOT tested */
       IsEqualGUID (&subtype_guid, &MEDIASUBTYPE_CFCC) ||        /* FIXME: NOT tested */
       IsEqualGUID (&subtype_guid, &MEDIASUBTYPE_IJPG)) {        /* FIXME: NOT tested */
-    media_type = "image/jpeg";
-  } else if (IsEqualGUID (&subtype_guid, &MEDIASUBTYPE_RGB555)) {
-    media_type = "video/x-raw";
-    format = "RGB15";
-    is_rgb = TRUE;
-  } else if (IsEqualGUID (&subtype_guid, &MEDIASUBTYPE_RGB565)) {
-    media_type = "video/x-raw";
-    format = "RGB16";
-    is_rgb = TRUE;
-  } else if (IsEqualGUID (&subtype_guid, &MEDIASUBTYPE_RGB24)) {
-    media_type = "video/x-raw";
-    format = "BGR";
-    is_rgb = TRUE;
-  } else if (IsEqualGUID (&subtype_guid, &MEDIASUBTYPE_RGB32)) {
-    media_type = "video/x-raw";
-    format = "BGRx";
-    is_rgb = TRUE;
-  } else if (IsEqualGUID (&subtype_guid, &MEDIASUBTYPE_ARGB32)) {
-    media_type = "video/x-raw";
-    format = "BGRA";
-    is_rgb = TRUE;
-  } else if (IsEqualGUID (&subtype_guid, &MEDIASUBTYPE_ARGB1555)) {
-    GST_WARNING ("Unsupported video format ARGB15555");
-  } else if (IsEqualGUID (&subtype_guid, &MEDIASUBTYPE_ARGB4444)) {
-    GST_WARNING ("Unsupported video format ARGB4444");
-  } else if (memcmp (&subtype_guid.Data2, &MEDIASUBTYPE_FOURCC.Data2,
-          sizeof (subtype_guid) - sizeof (subtype_guid.Data1)) == 0) {
-    guint32 fourcc = subtype_guid.Data1;
-    gchar *format =
-        g_strdup_printf ("%" GST_FOURCC_FORMAT, GST_FOURCC_ARGS (fourcc));
-    if (GST_STR_FOURCC (format) == GST_MAKE_FOURCC ('Y', '1', '6', ' ')) {
-      structure = gst_structure_new ("video/x-raw", "format",
-          G_TYPE_STRING, "GRAY16_LE", NULL);
+    structure = gst_structure_new ("image/jpeg", NULL);
+  } else if (IsEqualGUID (&subtype_guid, &MEDIASUBTYPE_RGB555) ||       /* FIXME: NOT tested */
+      IsEqualGUID (&subtype_guid, &MEDIASUBTYPE_RGB565) ||      /* FIXME: NOT tested */
+      IsEqualGUID (&subtype_guid, &MEDIASUBTYPE_RGB24) || IsEqualGUID (&subtype_guid, &MEDIASUBTYPE_RGB32) ||   /* FIXME: NOT tested */
+      IsEqualGUID (&subtype_guid, &MEDIASUBTYPE_ARGB1555) ||    /* FIXME: NOT tested */
+      IsEqualGUID (&subtype_guid, &MEDIASUBTYPE_ARGB32) ||      /* FIXME: NOT tested */
+      IsEqualGUID (&subtype_guid, &MEDIASUBTYPE_ARGB4444)) {    /* FIXME: NOT tested */
+    guint depth = 0, bpp = 0;
+    gint endianness = 0;
+    guint32 r_mask = 0, b_mask = 0, g_mask = 0;
+
+    if (IsEqualGUID (&subtype_guid, &MEDIASUBTYPE_RGB555)) {
+      bpp = 16;
+      depth = 15;
+      endianness = G_BIG_ENDIAN;
+      r_mask = 0x7c00;
+      g_mask = 0x03e0;
+      b_mask = 0x001f;
+    } else if (IsEqualGUID (&subtype_guid, &MEDIASUBTYPE_RGB565)) {
+      bpp = depth = 16;
+      endianness = G_BIG_ENDIAN;
+      r_mask = 0xf800;
+      g_mask = 0x07e0;
+      b_mask = 0x001f;
+    } else if (IsEqualGUID (&subtype_guid, &MEDIASUBTYPE_RGB24)) {
+      bpp = depth = 24;
+      endianness = G_BIG_ENDIAN;
+      r_mask = 0x0000ff;
+      g_mask = 0x00ff00;
+      b_mask = 0xff0000;
+    } else if (IsEqualGUID (&subtype_guid, &MEDIASUBTYPE_RGB32)) {
+      bpp = 32;
+      depth = 24;
+      endianness = G_BIG_ENDIAN;
+      r_mask = 0x000000ff;
+      g_mask = 0x0000ff00;
+      b_mask = 0x00ff0000;
+      /* FIXME: check
+       *r_mask = 0xff000000;
+       *g_mask = 0x00ff0000;
+       *b_mask = 0x0000ff00;
+       */
+    } else if (IsEqualGUID (&subtype_guid, &MEDIASUBTYPE_ARGB1555)) {
+      bpp = 16;
+      depth = 15;
+      endianness = G_BIG_ENDIAN;
+      r_mask = 0x7c00;
+      g_mask = 0x03e0;
+      b_mask = 0x001f;
+    } else if (IsEqualGUID (&subtype_guid, &MEDIASUBTYPE_ARGB32)) {
+      bpp = depth = 32;
+      endianness = G_BIG_ENDIAN;
+      r_mask = 0x000000ff;
+      g_mask = 0x0000ff00;
+      b_mask = 0x00ff0000;
+      /* FIXME: check
+       *r_mask = 0xff000000;
+       *g_mask = 0x00ff0000;
+       *b_mask = 0x0000ff00;
+       */
+    } else if (IsEqualGUID (&subtype_guid, &MEDIASUBTYPE_ARGB4444)) {
+      bpp = 16;
+      depth = 12;
+      endianness = G_BIG_ENDIAN;
+      r_mask = 0x0f00;
+      g_mask = 0x00f0;
+      b_mask = 0x000f;
+      //r_mask = 0x000f;
+      //g_mask = 0x00f0;
+      //b_mask = 0x0f00;
     } else {
-      structure = gst_structure_new ("video/x-raw", "format",
-          G_TYPE_STRING, format, NULL);
+      g_assert_not_reached ();
     }
-    g_free (format);
+
+    structure = gst_structure_new ("video/x-raw-rgb",
+        "bpp", G_TYPE_INT, bpp,
+        "depth", G_TYPE_INT, depth,
+        "red_mask", G_TYPE_INT, r_mask,
+        "green_mask", G_TYPE_INT, g_mask,
+        "blue_mask", G_TYPE_INT, b_mask,
+        "endianness", G_TYPE_INT, endianness, NULL);
   } else if (IsEqualGUID (&subtype_guid, &MEDIASUBTYPE_dvsd)) {
     if (IsEqualGUID (&format_guid, &FORMAT_DvInfo)) {
       structure = gst_structure_new ("video/x-dv",
@@ -182,27 +221,23 @@ ks_video_format_to_structure (GUID subtype_guid, GUID format_guid,
     } else if (IsEqualGUID (&format_guid, &FORMAT_VideoInfo)) {
       structure = gst_structure_new ("video/x-dv",
           "systemstream", G_TYPE_BOOLEAN, FALSE,
-          "format", G_TYPE_STRING, "dvsd", NULL);
+          "format", GST_TYPE_FOURCC, GST_MAKE_FOURCC ('d', 'v', 's', 'd'),
+          NULL);
     }
-  }
+  } else if (memcmp (&subtype_guid.Data, &MEDIASUBTYPE_FOURCC.Data,
+          sizeof (subtype_guid) - sizeof (subtype_guid.Data1)) == 0) {
+    guint8 *p = (guint8 *) & subtype_guid.Data1;
 
-  if (media_type) {
-    structure = gst_structure_new_empty (media_type);
-    if (format) {
-      gst_structure_set (structure, "format", G_TYPE_STRING, format, NULL);
-    }
-    if (p_is_rgb) {
-      *p_is_rgb = is_rgb;
-    }
+    structure = gst_structure_new ("video/x-raw-yuv",
+        "format", GST_TYPE_FOURCC, GST_MAKE_FOURCC (p[0], p[1], p[2], p[3]),
+        NULL);
   }
 
   if (!structure) {
-    GST_DEBUG ("Unknown DirectShow Video GUID "
-        "%08x-%04x-%04x-%02x%02x-%02x%02x%02x%02x%02x%02x",
-        (guint) subtype_guid.Data1, subtype_guid.Data2, subtype_guid.Data3,
-        subtype_guid.Data4[0], subtype_guid.Data4[1], subtype_guid.Data4[2],
-        subtype_guid.Data4[3], subtype_guid.Data4[4], subtype_guid.Data4[5],
-        subtype_guid.Data4[6], subtype_guid.Data4[7]);
+    GST_DEBUG ("Unknown DirectShow Video GUID %08x-%04x-%04x-%04x-%08x%04x",
+        subtype_guid.Data1, subtype_guid.Data, subtype_guid.Data3,
+        *(WORD *) subtype_guid.Data4, *(DWORD *) & subtype_guid.Data4[2],
+        *(WORD *) & subtype_guid.Data4[6]);
   }
 
   return structure;
@@ -212,7 +247,7 @@ static void
 guess_aspect (gint width, gint height, gint * par_width, gint * par_height)
 {
   /*
-   * As we don't have access to the actual pixel aspect, we will try to do a
+   * As we dont have access to the actual pixel aspect, we will try to do a
    * best-effort guess. The guess is based on most sensors being either 4/3
    * or 16/9, and most pixel aspects being close to 1/1.
    */
@@ -463,10 +498,9 @@ ks_video_probe_filter_for_caps (HANDLE filter_handle)
         guint i;
 
         for (i = 0; i < items->Count; i++) {
-          if (IsEqualGUID (&range->MajorFormat, &MEDIATYPE_Video)
-              || IsEqualGUID (&range->MajorFormat, &MEDIATYPE_Interleaved)) {
+          if (IsEqualGUID (&range->MajorFormat, &KSDATAFORMAT_TYPE_VIDEO)) {
             KsVideoMediaType *entry;
-            gpointer src_vscc = NULL, src_format = NULL;
+            gpointer src_vscc, src_format;
             GstStructure *media_structure;
 
             entry = g_new0 (KsVideoMediaType, 1);
@@ -503,22 +537,16 @@ ks_video_probe_filter_for_caps (HANDLE filter_handle)
               entry->sample_size =
                   vr->VideoInfoHeader.hdr.bmiHeader.biSizeImage;
             } else if (IsEqualGUID (&range->Specifier, &FORMAT_MPEG2Video)) {
+              /* Untested and probably wrong... */
               KS_DATARANGE_MPEG2_VIDEO *vr =
                   (KS_DATARANGE_MPEG2_VIDEO *) entry->range;
+
               src_vscc = &vr->ConfigCaps;
               src_format = &vr->VideoInfoHeader;
 
               entry->format_size = sizeof (vr->VideoInfoHeader);
               entry->sample_size =
                   vr->VideoInfoHeader.hdr.bmiHeader.biSizeImage;
-            } else if (IsEqualGUID (&range->Specifier, &FORMAT_DvInfo)) {
-              KS_DATARANGE_DVVIDEO *vr = (KS_DATARANGE_DVVIDEO *) entry->range;
-
-              src_vscc = NULL;
-              src_format = &vr->DVVideoInfo;
-
-              entry->format_size = sizeof (vr->DVVideoInfo);
-              entry->sample_size = vr->DataRange.SampleSize;
             } else {
               gchar *guid_str;
 
@@ -531,40 +559,22 @@ ks_video_probe_filter_for_caps (HANDLE filter_handle)
               entry = NULL;
             }
 
-            /* XXX: We've been doing g_assert (entry->sample_size != 0)
-             * since more than 10 years ago, but it's quite questionable.
-             * According to MS documentation,
-             * SampleSize field in KSDATARANGE struct is ignored,
-             * and biSizeImage in KS_BITMAPINFOHEADER is required only if
-             * compression is used. (driver maybe set zero for raw image).
-             * But since we've expected the value shouldn't be zero,
-             * let's ignore a media type with entry->sample_size == 0 for now.
-             * Actually people should not use this plugin in newly written code
-             * anymore */
-            if (entry && entry->sample_size == 0)
-              g_clear_pointer (&entry, ks_video_media_type_free);
-
             if (entry != NULL) {
-              if (src_vscc != NULL) {
-                memcpy ((gpointer) & entry->vscc, src_vscc,
-                    sizeof (entry->vscc));
-              }
+              g_assert (entry->sample_size != 0);
+
+              memcpy ((gpointer) & entry->vscc, src_vscc, sizeof (entry->vscc));
 
               entry->format = g_malloc (entry->format_size);
               memcpy (entry->format, src_format, entry->format_size);
 
               media_structure =
                   ks_video_format_to_structure (range->SubFormat,
-                  range->Specifier, &entry->is_rgb);
+                  range->MajorFormat);
 
               if (media_structure == NULL) {
                 g_warning ("ks_video_format_to_structure returned NULL");
                 ks_video_media_type_free (entry);
                 entry = NULL;
-              } else if (src_vscc == NULL) {
-                entry->translated_caps = gst_caps_new_empty ();
-                gst_caps_append_structure (entry->translated_caps,
-                    media_structure);
               } else if (ks_video_append_video_stream_cfg_fields
                   (media_structure, &entry->vscc)) {
                 entry->translated_caps = gst_caps_new_empty ();
@@ -706,56 +716,45 @@ ks_video_get_all_caps (void)
     /* RGB formats */
     structure =
         ks_video_append_var_video_fields (ks_video_format_to_structure
-        (MEDIASUBTYPE_RGB555, FORMAT_VideoInfo, NULL));
+        (MEDIASUBTYPE_RGB555, FORMAT_VideoInfo));
     gst_caps_append_structure (caps, structure);
 
     structure =
         ks_video_append_var_video_fields (ks_video_format_to_structure
-        (MEDIASUBTYPE_RGB565, FORMAT_VideoInfo, NULL));
+        (MEDIASUBTYPE_RGB565, FORMAT_VideoInfo));
     gst_caps_append_structure (caps, structure);
 
     structure =
         ks_video_append_var_video_fields (ks_video_format_to_structure
-        (MEDIASUBTYPE_RGB24, FORMAT_VideoInfo, NULL));
+        (MEDIASUBTYPE_RGB24, FORMAT_VideoInfo));
     gst_caps_append_structure (caps, structure);
 
     structure =
         ks_video_append_var_video_fields (ks_video_format_to_structure
-        (MEDIASUBTYPE_RGB32, FORMAT_VideoInfo, NULL));
+        (MEDIASUBTYPE_RGB32, FORMAT_VideoInfo));
     gst_caps_append_structure (caps, structure);
 
     /* YUV formats */
     structure =
-        ks_video_append_var_video_fields (gst_structure_new_empty
-        ("video/x-raw"));
+        ks_video_append_var_video_fields (gst_structure_new ("video/x-raw-yuv",
+            NULL));
     gst_caps_append_structure (caps, structure);
 
     /* Other formats */
     structure =
         ks_video_append_var_video_fields (ks_video_format_to_structure
-        (MEDIASUBTYPE_MJPG, FORMAT_VideoInfo, NULL));
+        (MEDIASUBTYPE_MJPG, FORMAT_VideoInfo));
     gst_caps_append_structure (caps, structure);
 
     structure =
         ks_video_append_var_video_fields (ks_video_format_to_structure
-        (MEDIASUBTYPE_dvsd, FORMAT_VideoInfo, NULL));
+        (MEDIASUBTYPE_dvsd, FORMAT_VideoInfo));
     gst_caps_append_structure (caps, structure);
 
     structure =                 /* no variable video fields (width, height, framerate) */
-        ks_video_format_to_structure (MEDIASUBTYPE_dvsd, FORMAT_DvInfo, NULL);
+        ks_video_format_to_structure (MEDIASUBTYPE_dvsd, FORMAT_DvInfo);
     gst_caps_append_structure (caps, structure);
   }
 
   return caps;
 }
-
-void
-gst_ks_debug_init (void)
-{
-  static gsize res = 0;
-  if (g_once_init_enter (&res)) {
-    GST_DEBUG_CATEGORY_INIT (gst_ks_debug, "ksvideosrc",
-        0, "Kernel streaming video source");
-    g_once_init_leave (&res, 1);
-  }
-}
